#ifndef NT2_INCLUDE_FUNCTIONS_MASK2LOGICAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MASK2LOGICAL_HPP_INCLUDED

#include <nt2/boolean/include/functions/mask2logical.hpp>

#endif
